<?php
namespace AIOSEO\Plugin\Addon\LocalBusiness\Utils;

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

use AIOSEO\Plugin\Common\Traits;

/**
 * Load file assets.
 *
 * @since 1.2.4
 */
class Assets {
	use Traits\Assets;

	/**
	 * Get the script handle to use for asset enqueuing.
	 *
	 * @since 1.2.4
	 *
	 * @var string
	 */
	private $scriptHandle = 'aioseo-local-business';

	/**
	 * Asset handles that should load as regular JS and not as modern JS module.
	 *
	 * @since 4.1.9
	 *
	 * @var array An array of handles.
	 */
	private $noModuleTag = [];

	/**
	 * Class constructor.
	 *
	 * @since 1.2.4
	 */
	public function __construct() {
		$this->core              = aioseo()->core;
		$this->version           = aioseoLocalBusiness()->version;
		$this->manifestFile      = AIOSEO_LOCAL_BUSINESS_DIR . '/dist/manifest.json';
		$this->assetManifestFile = AIOSEO_LOCAL_BUSINESS_DIR . '/dist/manifest-assets.json';
		$this->isDev             = aioseoLocalBusiness()->isDev;

		if ( $this->isDev ) {
			$this->domain = getenv( 'VITE_AIOSEO_LOCAL_BUSINESS_DOMAIN' );
			$this->port   = getenv( 'VITE_AIOSEO_LOCAL_BUSINESS_DEV_PORT' );
		}

		$this->noModuleTag = [
			'src/js-api-loader.js'
		];

		add_filter( 'script_loader_tag', [ $this, 'scriptLoaderTag' ], 10, 2 );
	}

	/**
	 * Get the public URL base.
	 *
	 * @since 1.2.4
	 *
	 * @return string The URL base.
	 */
	private function getPublicUrlBase() {
		return $this->shouldLoadDev() ? '/dist' : $this->basePath();
	}

	/**
	 * Get the base path URL.
	 *
	 * @since 1.2.4
	 *
	 * @return string The base path URL.
	 */
	private function basePath() {
		return plugins_url( 'dist/', AIOSEO_LOCAL_BUSINESS_FILE );
	}
}